==> haskell-mono-traversable-1.0.2-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.2
id: mono-traversable-1.0.2-67BKxTPGZubKwAv6XkqpFt
key: mono-traversable-1.0.2-67BKxTPGZubKwAv6XkqpFt
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Monomorphic variants of the Functor, Foldable, and Traversable typeclasses. If you understand Haskell'\''s basic typeclasses, you understand mono-traversable. In addition to what you are used to, it adds on an IsSequence typeclass and has code for marking data structures as non-empty.
category: Data
author: Michael Snoyman, John Wiegley, Greg Weber
exposed: True
exposed-modules:
    Data.MonoTraversable Data.MonoTraversable.Unprefixed
    Data.Containers Data.Sequences Data.NonNull
abi: 49cd12444ab4ded508bbbbcb7f34218f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/mono-traversable-1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/mono-traversable-1.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/mono-traversable-1.0.2
hs-libraries: HSmono-traversable-1.0.2-67BKxTPGZubKwAv6XkqpFt
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    vector-algorithms-0.7.0.1-7hkZdPzlc60Fe3nqzzgmcD
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mono-traversable
version: 1.0.2
id: mono-traversable-1.0.2-K5Z4ktfMwTB7vAbcHSGylk
key: mono-traversable-1.0.2-K5Z4ktfMwTB7vAbcHSGylk
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/snoyberg/mono-traversable
synopsis: Type classes for mapping, folding, and traversing monomorphic containers
description:
    Monomorphic variants of the Functor, Foldable, and Traversable typeclasses. If you understand Haskell'\''s basic typeclasses, you understand mono-traversable. In addition to what you are used to, it adds on an IsSequence typeclass and has code for marking data structures as non-empty.
category: Data
author: Michael Snoyman, John Wiegley, Greg Weber
exposed: True
exposed-modules:
    Data.MonoTraversable Data.MonoTraversable.Unprefixed
    Data.Containers Data.Sequences Data.NonNull
abi: ca6f711e211f317360f1b13dce7d31db
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/mono-traversable-1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/mono-traversable-1.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/mono-traversable-1.0.2
hs-libraries: HSmono-traversable-1.0.2-K5Z4ktfMwTB7vAbcHSGylk
depends:
    base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
    vector-algorithms-0.7.0.1-5uWiEsia2ll7iojszUQtFk
haddock-interfaces: /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock
haddock-html: /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
